handle_app_log

Function handle_app_log 

pub fn handle_app_log(buf: &[u8], component_id: &str)
Handle an application log. Has the potential to both forward the log to OTel and to emit it as a tracing event.